@@ -1,4 +1,4 @@
-"procuste.randtest" <- function(df1, df2, nrepet=999) {
+"procuste.randtest" <- function(df1, df2, nrepet = 999, ...) {
     if (!is.data.frame(df1)) 
         stop("data.frame expected")
     if (!is.data.frame(df2)) 
@@ -16,10 +16,10 @@
     tra2 <- sum(var2)
     X <- X/sqrt(tra1)
     Y <- Y/sqrt(tra2)
-    lig<-nrow(X)
-    c1<-ncol(X)
-    c2<-ncol(Y)
-    isim<-testprocuste(nrepet, lig, c1, c2, as.matrix(X), as.matrix(Y))
-    obs<-isim[1]
-    return(as.randtest(isim[-1],obs,call=match.call()))
+    X <- as.matrix(X)
+    Y <- as.matrix(Y)
+	rv1 <- procusterandtestCpp(X, Y, nrepet)
+    obs <- rv1[1]
+    w <- as.randtest(obs = obs, sim = rv1[-1], call = match.call(), ...)
+    return(w)
 }
