@@ -23,12 +23,12 @@ randtest.amova <- function(xtest, nrepet = 99, ...) {
         res <- testamova(distances, nrow(distances), nrow(distances), samples, nrow(samples), ncol(samples), structures, nrow(structures), ncol(structures), indic, sum(samples), nrepet, lesss[length(lesss)] / sum(samples), ddl, longueurresult)
         restests <- matrix(res, nrepet, length(sigma) - 1, byrow = TRUE)
         alts <- rep("greater", length(names(structures)) + 1)
-        permutationtests <- as.krandtest(sim=restests,obs=sigma[(length(sigma) - 1):1],names= paste("Variations", c("within samples", "between samples", paste("between", names(structures)))),alter=c("less", alts),call=match.call())
+        permutationtests <- as.krandtest(sim=restests,obs=sigma[(length(sigma) - 1):1],names = paste("Variations", c("within samples", "between samples", paste("between", names(structures)))), alter=c("less", alts), call = match.call(), ...)
     }
     else {
         longueurresult <- nrepet * (length(sigma) - 2)
         res <- testamova(distances, nrow(distances), nrow(distances), samples, nrow(samples), ncol(samples), structures, nrow(structures), ncol(structures), indic, sum(samples), nrepet, lesss[length(lesss)] / sum(samples), ddl, longueurresult)
-        permutationtests <- as.randtest(res, sigma[1])
+        permutationtests <- as.randtest(sim = res, obs = sigma[1], ...)
     }
     return(permutationtests)
 }
